==> zanshin_0.5.0.orig.tar.xz: zanshin-0.5.0/src/akonadi/akonaditimestampattribute.h <==
/* This file is part of Zanshin

   Copyright 2014 Kevin Ottens <ervin@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
   USA.
*/

#ifndef AKONADI_TIMESTAMPATTRIBUTE_H
#define AKONADI_TIMESTAMPATTRIBUTE_H

#include <QByteArray>

#include <AkonadiCore/Attribute>

namespace Akonadi {

class TimestampAttribute : public Attribute
{
public:
    TimestampAttribute();
    ~TimestampAttribute();

    qint64 timestamp() const;
    void refreshTimestamp();

    QByteArray type() const Q_DECL_OVERRIDE;
    TimestampAttribute *clone() const Q_DECL_OVERRIDE;

    QByteArray serialized() const Q_DECL_OVERRIDE;
    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;

private:
    qint64 m_timestamp;
};

}

#endif

==> zanshin_0.5.71.orig.tar.xz: zanshin-0.5.71/src/akonadi/akonaditimestampattribute.h <==
/* This file is part of Zanshin

   Copyright 2014 Kevin Ottens <ervin@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
   USA.
*/

#ifndef AKONADI_TIMESTAMPATTRIBUTE_H
#define AKONADI_TIMESTAMPATTRIBUTE_H

#include <QByteArray>

#include <AkonadiCore/Attribute>

namespace Akonadi {

class TimestampAttribute : public Attribute
{
public:
    TimestampAttribute();
    ~TimestampAttribute();

    qint64 timestamp() const;
    void refreshTimestamp();

    QByteArray type() const override;
    TimestampAttribute *clone() const override;

    QByteArray serialized() const override;
    void deserialize(const QByteArray &data) override;

private:
    qint64 m_timestamp;
};

}

#endif
